@@ -3,9 +3,7 @@
 """ 
 from typing import Callable
 from fastapi import FastAPI
-from ..redis.redis import redis_init 
-import os
-from ...settings import config
+from ..redis.redis import redis_init  
 
 
 # app 启动
