@@ -2,26 +2,22 @@
 import re
 from itertools import groupby
 
-class regularExtrator():
+from ..reg import RegularExtrator_txt as pre
 
-    def __init__(self, text):
+class RegularExtrator(pre):
+ 
+    def __init__(self, text='',data_list = []):
+        pre.__init__(self, text,data_list)  
         self.text = text
+        self.data_list = data_list
 
     def remove_chinese(self):
         if self.text == "":
             return ""
         pattern = re.compile(u'[\u4E00-\u9FA5]')
         text_without_chinese = pattern.sub(r"", self.text)
-        return text_without_chinese
-
-    def clear_data(self):
-        # 去除空格换行符等字符的txt文本列表 
-        if self.text == "":
-            return ""
-        pattern = r'[\s]*'
-        txt_drop = re.sub(pattern, '', self.text)       # 清除换行,制表,空格 
-        return txt_drop 
-
+        return text_without_chinese 
+    
     #email抽取
     def extract_email(self):
         if self.text == "":
